"""
    Universal Binary Archiver Service

    Universal Binary Archiver Service  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import ubai_client
from ubai_client.api.search_api import SearchApi  # noqa: E501


class TestSearchApi(unittest.TestCase):
    """SearchApi unit test stubs"""

    def setUp(self):
        self.api = SearchApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_find_all_artifacts(self):
        """Test case for find_all_artifacts

        """
        pass

    def test_find_first_artifact(self):
        """Test case for find_first_artifact

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Universal Binary Archiver Service

    Universal Binary Archiver Service  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import ubai_client
from ubai_client.model.artifact_storage import ArtifactStorage


class TestArtifactStorage(unittest.TestCase):
    """ArtifactStorage unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testArtifactStorage(self):
        """Test ArtifactStorage"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ArtifactStorage()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
